cmd

package
v0.0.0-...-ebc097b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 19, 2026 License: MIT Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute() error

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

Types

type HTTPSWrenchConfig

type HTTPSWrenchConfig struct {
	Debug                       bool   `mapstructure:"debug"`
	Verbose                     bool   `mapstructure:"verbose"`
	CaBundle                    string `mapstructure:"caBundle"`
	requests.RequestsMetaConfig `mapstructure:",squash"`
}

HTTPSWrenchConfig represents the top-level configuration for the application.

func LoadConfig

func LoadConfig() (*HTTPSWrenchConfig, error)

LoadConfig reads the configuration file and unmarshals it into an HTTPSWrenchConfig struct.

func NewHTTPSWrenchConfig

func NewHTTPSWrenchConfig() *HTTPSWrenchConfig

NewHTTPSWrenchConfig returns a new HTTPSWrenchConfig with default values.

Jump to